
Publications
==============

[1] Garyfallidis E, Brett M, Amirbekian B, Rokem A, van der Walt S, Descoteaux M, Nimmo-Smith I and Dipy Contributors (2014). `DIPY, a library for the analysis of diffusion MRI data. <http://journal.frontiersin.org/Journal/10.3389/fninf.2014.00008/abstract>`_ Frontiers in Neuroinformatics, vol.8, no.8.

[2] Garyfallidis E, Brett M, Nimmo-Smith I (2010), “Fast Dimensionality Reduction for Brain Tractography Clustering”, 16th Annual Meeting of the Organization for Human Brain Mapping.

[3] Garyfallidis E, Brett M, Tsiaras V, Vogiatzis G, Nimmo-Smith I (2010), “Identification of corresponding tracks in diffusion MRI tractographies” Proc. Intl. Soc. Mag. Reson. Med. 18

[4] Correia M.M, Williams G.B, Yeh F-C, Nimmo-Smith I, Garyfallidis E (2011), “Robustness of diffusion scalar metrics when estimated with Generalized Q-Sampling Imaging acquisition schemes”, Proc. Intl. Soc. Mag. Reson. Med. 19

[5] Chamberlain SR, Hampshire A, Menzies LA, Garyfallidis E, Grant JE, Odlaug BL, Craig K, Fineberg N, Sahakian BJ (2010), “Reduced brain white matter integrity in trichotillomania: a diffusion tensor imaging study.” Arch Gen Psychiatry 67(9):965-71

[6] Garyfallidis E, Brett M, Amirbekian B, Nguyen C, Yeh F-C, Olivetti E, Halchenko Y, Nimmo-Smith I (2011), "Dipy - a novel software library for diffusion MR and tractography", 17th Annual Meeting of the Organization for Human Brain Mapping.

[7] Yeh F-C, Wedeen VJ, Tseng WY (2010), "Generalized Q-Sampling Imaging", IEEE Trans. Med. Imaging.

[8] Garyfallidis E, Brett M, Correia M.M, Williams G.B, Nimmo-Smith I. (2012), "QuickBundles, a method for tractography simplification", Frontiers in
Neuroscience, 6 (175).

[9] Garyfallidis E, Cote M-A, Rheault F, Sidhu J, Hau J, Petit L, Fortin D, Cunanne S, Descoteaux M,  `Recognition of white matter bundles using local and global streamline-based registration and clustering. <http://www.sciencedirect.com/science/article/pii/S1053811917305839>`_

[10] Garyfallidis E, Ocegueda O, Wassermann D, Descoteaux M. `Robust and efficient linear registration of white-matter fascicles in the space of streamlines. <http://www.sciencedirect.com/science/article/pii/S1053811915003961>`_

[11] Rokem A, Yeatman JD, Pestilli F, Kay KN, Mezer A, et al. (2015), `Evaluating the Accuracy of Diffusion MRI Models in White Matter. <http://journals.plos.org/plosone/article?id=10.1371/journal.pone.0123272>`_

[12] Ocegueda O, Dalmau O, Garyfallidis E, Descoteaux M, Rivera M, `On the computation of integrals over fixed-size rectangles of arbitrary dimension. <http://www.sciencedirect.com/science/article/pii/S0167865516300861>`_

[13] Rafael Neto Henriques, Ariel Rokem, Eleftherios Garyfallidis, Samuel St-Jean, Eric Thomas Peterson, Marta Morgado Correia, ReScience volume 3, issue 1, article number 2, 2017
`[Re] Optimization of a free water elimination two-compartment model for diffusion tensor imaging. <https://www.biorxiv.org/content/early/2017/02/15/108795>`_


A note on citing our work
--------------------------

* The main reference citation for DIPY is [1].

* If you are using QuickBundles method please also cite [8].

* If you are using track correspondence also cite [3].

* If you are using Generalized Q-sampling please also cite [7].

